# Plots the spectra from an AGES catalogue and the standard output text spectra
# Looks for files which have the HID or HRID parameter in their name
# Assumes the files have been baseline subtracted. Plots the spectrum +/- 1000 
# km/s around the source. Sets the flux range to be -5x rms - 1.25x peak flux

import os
import matplotlib
matplotlib.use('agg')
from matplotlib import pyplot
import matplotlib.pyplot as plt

# LaTeX like fonts in the figure
plt.rc('font', family='serif')

titlessize = 15
numbersize = 12

csfont = {'fontname':'Liberation Serif','fontsize':titlessize}


from matplotlib.ticker import AutoMinorLocator
XminorLocator = AutoMinorLocator()
YminorLocator = AutoMinorLocator()


# Disable interactive plotting
pyplot.ioff()


# Change to directory where script is located
abspath = os.path.abspath(__file__)
dname = os.path.dirname(abspath)
os.chdir(dname)

# Whitespace separated catalogue file from formatta script, with extra HRID column
CatFile = open('Leo_HItable.txt','r')

chn = []
vel = []
flx = []

for line in CatFile:
	if '#' in line:
		continue
	else:
		HID, HRID, RAs, RA, eRA, Decs, Dec, eDec, vc, evc, wmax, ewmax, wmin, ewmin, pf, epf, tf, etf, m, snp, snt, rms, field, aasn, hicode = line.split() 
		# Check if files exist
		HIDFile = os.path.isfile(HID+'_logspec.txt')
		HRIDFile= os.path.isfile(HRID+'_logspec.txt')
						
		# Choose which filename to use for the postscript, depending on whether
		# files with the standard or human-readable files exist
		if str(HIDFile) == 'False' and str(HRIDFile) == 'False':
			continue
		if str(HIDFile) == 'True' and str(HRIDFile) == 'False':
			infile = open(str(HID)+'_logspec.txt','r')
			outfile1 = str(HID)+'.ps'
			outfile2 = str(HID)+'.png'
			outfile3 = str(HID)+'_miriad.png'
		if str(HIDFile) == 'False' and str(HRIDFile) == 'True':
			infile = open(str(HRID)+'_logspec.txt','r')
			outfile1 = str(HRID)+'.ps'
			outfile2 = str(HRID)+'.png'
			outfile3 = str(HRID)+'_miriad.png'			
		if str(HIDFile) == 'True' and str(HRIDFile) == 'True':
			infile = open(str(HID)+'_logspec.txt','r')
			outfile1 = str(HID)+'.ps'
			outfile2 = str(HID)+'.ps'
			outfile3 = str(HID)+'_miriad.png'
	
		# If files exist, do the plotting. Skip commented lines.
		if str(HIDFile) == 'True' or str(HRIDFile) == 'True':
			for line in infile:
				if '#' in line:
					# Get arrays of mask and profile windows for plotting
					if 'mask' in line:
						# Split the line into its component mask start and end points
						masklist = line.split('=')[1].split(',')
						# Convert list of strings to list of floats
						masklist = [float(i) for i in masklist]
					
					if 'profile' in line:
						proflist = line.split('=')[1].split(',')
						proflist = [float(i) for i in proflist]
						
					if 'MXC' in line :
						W50lc = 	line.split()[3]
						W20lc = 	line.split()[4]
							
					continue
					
				c,v,f = line.split()
				chn.append(float(c))
				vel.append(float(v))
				flx.append(float(f)/1E-3)	# Get flux in mJy
		
			vmin = float(vc) - 500.0
			vmax = float(vc) + 500.0
		
			fmin = -5.0*float(rms)
			fmax = 1.25*float(pf)
			
			# W50 and W20 positions - wmax/min terms are misleading and should be renamed ! 
			vw50low = None
			vw50hgh = None
			vw20low = None
			vw20hgh = None
			# Inlcude checks since on occasion these parameters will not be defined
			if type(W50lc) is float and type(wmax) is float:
				vw50low = float(W50lc) - (float(wmax)/2.0)	
				vw50hgh = float(W50lc) + (float(wmax)/2.0)
			if type(W20lc) is float and type(wmin) is float:	
				vw20low = float(W20lc) - (float(wmin)/2.0)
				vw20hgh = float(W20lc) + (float(wmin)/2.0)			
			
			
			fig=pyplot.figure()
			fig.set_size_inches(750.0/100.0,750.0/100.0)
			
			pyplot.plot(vel,flx, color='black', linewidth=0.5)
							
			
			pyplot.xlim((vmin,vmax))
			pyplot.ylim((fmin,fmax))
			pyplot.xlabel('Velocity / km s$^{-1}$', **csfont)
			pyplot.ylabel('Flux / mJy', **csfont)
			pyplot.title(str(HRID))
		
			plot = fig.add_subplot(111)
			plot.tick_params(axis='both', which='major', labelsize=numbersize)
			
			ax = plt.axes()
			ax.xaxis.set_minor_locator(XminorLocator)
			ax.yaxis.set_minor_locator(YminorLocator)
			
			ax.tick_params(which='major', length=10)
			ax.tick_params(which='minor', length=5)
			
			pyplot.savefig(outfile1,dpi=100,facecolor='white',bbox_inches='tight')
			pyplot.savefig(outfile2,dpi=100,facecolor='white',bbox_inches='tight')
			
			
			# Second miriad-like version
			# Plot vertical lines for the mask and profile windows
			#for i in masklist:
			#	plt.axvline(x=i, linestyle = '--', color='blue')
			
			for i in proflist:
				plt.axvline(x=i, linestyle = ':', color='red')
				
			# Plot circles for W50 and squares for W20
			#circleW50_min = plt.Circle((vw50low, float(pf)/2.0), 1.0, color='blue', fill=False)
			#ax.add_patch(circleW50_min)
			
			plt.scatter(vw50low, float(pf)/2.0, facecolors='none', edgecolors='blue', s=50)
			plt.scatter(vw50hgh, float(pf)/2.0, facecolors='none', edgecolors='blue', s=50)
			plt.scatter(vw20low, float(pf)/5.0, marker="s", facecolors='none', edgecolors='blue', s=50)
			plt.scatter(vw20hgh, float(pf)/5.0, marker="s", facecolors='none', edgecolors='blue', s=50)			
			
			pyplot.savefig(outfile3,dpi=100,facecolor='white',bbox_inches='tight')
		
			pyplot.close('all')
			
			chn = []
			vel = []
			flx = []
			
